Programs Similar to Quizdrill

The current version of this file is availible at our wiki-page.

# Quizdrill/Similar Programs

OpenFacts, the Open Source Knowledge Database

< Quizdrill

Quizdrill was inspired by langdrill, a language drill program. No code came from either, however the quizzes eng-fra.drill, eng-jpn.drill, eng-jpn_romaji.drill and eng-svd.drill are taken directly from langdrill (french.drill, japanese.drill, romaji.drill and swedish.drill). An other program which offers multiple choice asking is AKFQuiz. As opposed to any of these, quizdrill should ask the questions depending on previous answers to make learning as efficient as possible. Note however, that a lot of work still needs to be done.

Programs which also offer efficient learning include granule, Pauker or mnemosyne. At the moment these have more aggressive learning strategies at the cost of only offering flash cards (as opposed to multiple choice, simple quiz and flash cards) and being more in the way of the user (e. g. by asking the user to score how well he remembered it).

If you are looking for a program for children which has a more friendly approach, GCompris and Schoolsplay have nice approaches.

Note: All of these Programs are FLOSS (Free-/ Libre-/ Open Source Software) meeting the the DFSG, Free Software Definition and OSI-approved.